@@ -227,16 +227,23 @@ THIS MODULE ISN'T USABLE WITH MARIADB FOR NOW.
 L<Apache::Session>, L<Apache::Session::Browseable::MySQL>,
 L<http://lemonldap-ng.org>
 
-=head1 AUTHOR
-
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
 =encoding utf8
 
-Copyright (C) 2009-2017 by Xavier Guimard
-              2013-2017 by Clément Oudot
+=over
+
+=item 2009-2025 by Xavier Guimard
+
+=item 2013-2025 by Clément Oudot
+
+=item 2019-2025 by Maxime Besson
+
+=item 2013-2025 by Worteks
+
+=item 2023-2025 by Linagora
+
+=back
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.1 or,
